trigger

Enum trigger 

pub enum trigger {
    attack,
    release,
    first,
    legato,
    release_key,
}
Sets the trigger which will be used for the sample to play.

Variants



attack

(Default): Region will play on note-on.



release

Region will play on note-off or sustain pedal off. The velocity used to play the note-off sample is the velocity value of the corresponding (previous) note-on message.



first

Region will play on note-on, but if there’s no other note going on (comoonly used for or first note in a legato phrase).



legato

Region will play on note-on, but only if there’s a note going on (notes after first note in a legato phrase).



release_key

Region will play on note-off. Ignores sustain pedal.

Implementations

Source

impl trigger

pub fn from_name(name: &str) -> Option<Self>

Constructor from the variant name, as a string